@@ -1,8 +1,8 @@
+from email import header
 import json
-from pickle import FALSE
 import requests
 
-RENEWURL = "http://localhost:5000/auth/renewTokens"
+RENEWURL = "http://loclhost:5000/auth/renewTokens"
 class renewToken:
      def __init__(self,pubKey,refreshToken,keyId,userSubId):
         self.pubKey=pubKey
@@ -13,21 +13,28 @@ class renewToken:
 
     
      def renewToken(self):
-         
-         try: 
-            token=requests.post(RENEWURL,
-                    data=json.stringify({
+        print("TOKENS")
+        data={
                     "publicKey":self.pubKey,
                     "refreshToken":self.refreshToken,
                     "userSubId":self.userSubId,
-                    "renewRefreshToken":FALSE,
-                    }),headers={ 
+                    "renewRefreshToken":False,
+                    }
+        headers={ 
                     "Content-Type": "application/json",
                      "keyId":self.keyId
-                    })
+                    }
+         
+        try: 
+            token=requests.post(RENEWURL,headers=headers,json=data)
+            
+            print(token)
+            print(token.status_code)
+            print(token.json())
             return token;
-         except:
-            return{}
+        except :
+             print("exception")
+             return{}
 
             
 
